<?php

namespace Drupal\Tests\responsive_image_link_formatter\Functional;

/**
 * @file
 * Contains Functional test cases for the 'responsive_image_link_formatter'.
 */

use Drupal\Tests\image_link_formatter\Traits\Functional\ImageLinkFormatterTestTrait;
use Drupal\Tests\responsive_image\Functional\ResponsiveImageFieldDisplayTest;
use Drupal\Tests\TestFileCreationTrait;

/**
 * Tests the output of a node with a responsive image wrapped within a link.
 *
 * Extends the core test case 'ResponsiveImageFieldDisplayTest' for the creation
 * of the base configuration objects (responsive image styles), user login,
 * needed for the tests ('setUp'). On top, the logic related with the 'link'
 * field is added by the trait 'ImageLinkFormatterTestTrait' which provides
 * common methods, such as the effective tests
 * ('doTestImageLinkFormatterWrappedImage', which also creates its 'image'
 * field), or their assertions ('assertImageLinkFormatter'), based on the
 * HTML results to be expected, defined by this object (for the
 * 'responsive_image_link_formatter).
 *
 * @group image_link_formatter
 * @see \Drupal\Tests\image_link_formatter\Functional\ImageLinkFormatterTest
 * @see \Drupal\Tests\image_link_formatter\Traits\Functional\ImageLinkFormatterTestTrait
 * @see \Drupal\Tests\responsive_image\Functional\ResponsiveImageFieldDisplayTest
 */
class ResponsiveImageLinkFormatterTest extends ResponsiveImageFieldDisplayTest {

  use TestFileCreationTrait {
    getTestFiles as drupalGetTestFiles;
  }

  use ImageLinkFormatterTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['field_ui', 'responsive_image_link_formatter'];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Tests the display of a responsive image wrapped within a custom link field.
   *
   * Defines the results to be expected for the supported Drupal versions and
   * calls the standard test method from the trait which displays a node with
   * the responsive image link formatter with and without a link and checks
   * whether the expected HTML is found on the page.
   *
   * @see \Drupal\Tests\image_link_formatter\Functional\ImageLinkFormatterTest::testImageLinkFormatterWrappedImage()
   * @see \Drupal\Tests\image_link_formatter\Traits\Functional\ImageLinkFormatterTestTrait::doTestImageLinkFormatterWrappedImage()
   * @see \Drupal\Tests\image_link_formatter\Traits\Functional\ImageLinkFormatterTestTrait::assertImageLinkFormatter()
   */
  public function testResponsiveImageLinkFormatterWrappedImage() {
    // For each supported Drupal core version, provide the expected HTML result
    // specific to the test, with which to compare the output generated by the
    // formatter, based on the evolutions of the core 'image' module and its
    // formatters, for example with added attributes.
    // As of 10.1, lazy loading is part of core image formatter's
    // configuration but the position of the attribute changed.
    $expected_result = [
      'link' => '<a href="http://example.com"><img alt="" loading="lazy" src="@file_url" width="40" height="20" /></a>',
      'no_link' => '<img alt="" loading="lazy" src="@file_url" width="40" height="20" />',
    ];
    if (floatval(\Drupal::VERSION) < 10.1) {
      // Moving forward, attribute 'loading' added by default, see #3173719 and
      // as of 9.4.0, lazy loading is part of core image formatter's
      // configuration, changing the position of the attribute, see #3173180.
      $expected_result = [
        'link' => '<a href="http://example.com"><img alt="" src="@file_url" width="40" height="20" loading="lazy" /></a>',
        'no_link' => '<img alt="" src="@file_url" width="40" height="20" loading="lazy" />',
      ];
    }
    // Call the test from the trait for the 'responsive_image_link_formatter'.
    $this->doTestImageLinkFormatterWrappedImage('responsive_image_link_formatter', $expected_result);
  }

}
